function p = ghc(x)
% ghc - geometric Huffman coding
%   p = ghc(x) returns the dyadic probability mass function (pmf) that
%   minimizes the Kullback-Leibler distance D(p||x) among all
%   dyadic pmfs p.
%
%   x has to be a n-by-1 matrix with nonnegative entries.
%
%   Example:
%     p = ghc([0.1 0.2 0.3 0.4]') returns the 4-by-1 matrix:
%       p = 
%
%          0.12500
%          0.12500
%          0.25000
%          0.50000
%
%   See also nghc, ccghc, kldiv
%
% tested for octave 3.4.0, Matlab R2010b
% 29 June 2011
% (c) Georg Böcherer
% email: geborg@gmail.com

n = length(x);
indices = zeros(n-1,2);
cut_tree = false(n-1,1);

for k=1:n-1
    [~,index] = sort(x,'ascend');
    m = index(1:2);
    if(2*sqrt(x(m(1))*x(m(2)))<=x(m(2)))
        x = [x(1:m(1)-1);x(m(1)+1:end)];
        cut_tree(k)=true;
    else
	m = sort(m,'ascend');
	x = [x(1:m(1)-1);x(m(1)+1:m(2)-1);x(m(2)+1:end);2*sqrt(x(m(1))*x(m(2)))];
    end
    indices(k,:)=m;
end


L = zeros(n,1);
for k=1:n-1
    m = indices(n-k,:);
    if(cut_tree(n-k))
        L = [L(1:m(1)-1);Inf;L(m(1):k);L(k+2:end)];
    else
        L = [L(1:m(1)-1);L(k)+1;L(m(1):m(2)-2);L(k)+1;L(m(2)-1:k-1);L(k+2:end)];
    end
end

p = 2.^(-L);
