function y = kldiv(p,q)
% kldiv - Kullback-Leibler distance
%   D = kldiv(p,q) returns the Kullback-Leibler distance between
%   p and q, which is defined as sum_i p_i log(p_i/q_i). The convention
%   0 log 0 = 0 is applied.
%
%   p and q have to be n-by-1 matrices with nonnegative entries.
%
%   Example:
%     D = kldiv([0.1 0.9]',[0.9 0.1]') returns
%       D =  1.7578
%
%   See also ghc, nghc, ccghc
%
% tested for octave 3.4.0, Matlab R2010b
% 29 June 2011
% (c) Georg Böcherer
% email: geborg@gmail.com
y = p.*log(p./q);
y(isnan(y))=0;
y = sum(y);
