function p = nghc(x,w)
% nghc - normalized geometric Huffman coding
%   p = nghc(x) returns the dyadic probability mass function (pmf) that
%   minimizes the normalized Kullback-Leibler distance kldiv(p,x)/(w'*p)
%   among all dyadic pmfs p.
%
%   x has to be a n-by-1 matrix with nonnegative entries.
%   w has to be a n-by-1 matrix with positive entries.
%
%   Example:
%     p = nghc([1 1 1]',[1 2 3]) returns the 3-by-1 matrix:
%       p = 
%
%          0.50000
%          0.25000
%          0.25000
%
%   See also ghc, ccghc, kldiv
%
% tested for octave 3.4.0, Matlab R2010b
% 29 June 2011
% (c) Georg Böcherer
% email: geborg@gmail.com
D = 0;
D_old = Inf;

while(D~=D_old)
    p = ghc(x.*2.^(w*D));
    D_old = D;
    D = (kldiv(p,x)/log(2))/(w'*p);
end
